==> ncbi-vdb_3.0.2+dfsg.orig.tar.xz: ncbi-vdb-3.0.2/libs/vfs/manager-priv.h <==
#ifndef _h_libs_vfs_manager_
#define _h_libs_vfs_manager_

/*===========================================================================
*
*                            PUBLIC DOMAIN NOTICE
*               National Center for Biotechnology Information
*
*  This software/database is a "United States Government Work" under the
*  terms of the United States Copyright Act.  It was written as part of
*  the author's official duties as a United States Government employee and
*  thus cannot be copyrighted.  This software/database is freely available
*  to the public for use. The National Library of Medicine and the U.S.
*  Government have not placed any restriction on its use or reproduction.
*
*  Although all reasonable efforts have been taken to ensure the accuracy
*  and reliability of the software and data, the NLM and the U.S.
*  Government do not and cannot warrant the performance or results that
*  may be obtained by using this software or data. The NLM and the U.S.
*  Government disclaim all warranties, express or implied, including
*  warranties of performance, merchantability or fitness for any particular
*  purpose.
*
*  Please cite the author in any work or product based on this material.
*
* =========================================================================== */


#include <klib/text.h> /* String */


#ifdef __cplusplus
extern "C" {
#endif

    struct VFSManager;

    /* Get ".noqual" extension.
     *   accepts VFSManager* == NULL */
    const String * VFSManagerExtNoqual   (const struct VFSManager *);
    /* Get old ".noqual" extension. */
    const String * VFSManagerExtNoqualOld(const struct VFSManager *);
    /* Get ".sra" extension. */
    const String * VFSManagerExtSra      (const struct VFSManager *);

#ifdef __cplusplus
}
#endif


#endif /* _h_libs_vfs_manager_ */

==> ncbi-vdb_3.0.9+dfsg.orig.tar.xz: ncbi-vdb-3.0.9/libs/vfs/manager-priv.h <==
#ifndef _h_libs_vfs_manager_
#define _h_libs_vfs_manager_

/*===========================================================================
*
*                            PUBLIC DOMAIN NOTICE
*               National Center for Biotechnology Information
*
*  This software/database is a "United States Government Work" under the
*  terms of the United States Copyright Act.  It was written as part of
*  the author's official duties as a United States Government employee and
*  thus cannot be copyrighted.  This software/database is freely available
*  to the public for use. The National Library of Medicine and the U.S.
*  Government have not placed any restriction on its use or reproduction.
*
*  Although all reasonable efforts have been taken to ensure the accuracy
*  and reliability of the software and data, the NLM and the U.S.
*  Government do not and cannot warrant the performance or results that
*  may be obtained by using this software or data. The NLM and the U.S.
*  Government disclaim all warranties, express or implied, including
*  warranties of performance, merchantability or fitness for any particular
*  purpose.
*
*  Please cite the author in any work or product based on this material.
*
* =========================================================================== */


#include <klib/text.h> /* String */


#ifdef __cplusplus
extern "C" {
#endif

struct VFSManager;

/* Get ".noqual" extension.
    *   accepts VFSManager* == NULL */
const String * VFSManagerExtNoqual   (const struct VFSManager *);
/* Get old ".noqual" extension. */
const String * VFSManagerExtNoqualOld(const struct VFSManager *);
/* Get ".sra" extension. */
const String * VFSManagerExtSra      (const struct VFSManager *);

rc_t VFSManagerCheckRunDir(const KDirectory* dir, const struct VPath* path);

/******************************************************************************/
/* Cache of names resolve results / SDL responses */
typedef enum {
    eSCSEmpty,
    eSCSCachedWhenNull,
    eSCSCachedWhenNotNull,
    eSCSFound,
} ESdlCacheState;
uint32_t VFSManagerSdlCacheCount
(const struct VFSManager * self, ESdlCacheState * state);
rc_t VFSManagerSdlCacheClear(struct VFSManager * self);
/******************************************************************************/

#ifdef __cplusplus
}
#endif


#endif /* _h_libs_vfs_manager_ */
